@@ -755,6 +755,7 @@ pub struct MarianGenerator {
     is_encoder_decoder: bool,
     vocab_size: i64,
     decoder_start_id: Option<i64>,
+    max_position_embeddings: i64,
 }
 
 impl MarianGenerator {
@@ -826,6 +827,7 @@ impl MarianGenerator {
         let is_encoder_decoder = true;
         let decoder_start_id =
             Some(tokenizer.convert_tokens_to_ids(&[MarianVocab::pad_value()])[0]);
+        let max_position_embeddings = config.max_position_embeddings;
 
         Ok(MarianGenerator {
             model,
@@ -838,6 +840,7 @@ impl MarianGenerator {
             is_encoder_decoder,
             vocab_size,
             decoder_start_id,
+            max_position_embeddings,
         })
     }
 
@@ -883,6 +886,9 @@ impl PrivateLanguageGenerator<MarianForConditionalGeneration, MarianVocab, Maria
     fn get_decoder_start_id(&self) -> Option<i64> {
         self.decoder_start_id
     }
+    fn get_max_positions_embeddings(&self) -> i64 {
+        self.max_position_embeddings
+    }
 
     fn prepare_scores_for_generation(
         &self,
