@@ -864,6 +864,7 @@ pub struct ProphetNetConditionalGenerator {
     is_encoder_decoder: bool,
     vocab_size: i64,
     decoder_start_id: Option<i64>,
+    max_position_embeddings: i64,
 }
 
 impl ProphetNetConditionalGenerator {
@@ -964,6 +965,7 @@ impl ProphetNetConditionalGenerator {
         let vocab_size = config.vocab_size;
         let is_encoder_decoder = true;
         let decoder_start_id = Some(config.decoder_start_token_id);
+        let max_position_embeddings = config.max_position_embeddings;
 
         Ok(ProphetNetConditionalGenerator {
             model,
@@ -976,6 +978,7 @@ impl ProphetNetConditionalGenerator {
             is_encoder_decoder,
             vocab_size,
             decoder_start_id,
+            max_position_embeddings,
         })
     }
 }
@@ -1017,6 +1020,9 @@ impl
     fn get_decoder_start_id(&self) -> Option<i64> {
         self.decoder_start_id
     }
+    fn get_max_positions_embeddings(&self) -> i64 {
+        self.max_position_embeddings
+    }
 
     fn encode(&self, input_ids: &Tensor, attention_mask: Option<&Tensor>) -> Option<Tensor> {
         Some(
