@@ -1029,6 +1029,7 @@ pub struct ReformerGenerator {
     is_encoder_decoder: bool,
     vocab_size: i64,
     decoder_start_id: Option<i64>,
+    max_position_embeddings: i64,
 }
 
 impl ReformerGenerator {
@@ -1089,6 +1090,7 @@ impl ReformerGenerator {
         let vocab_size = config.vocab_size;
         let is_encoder_decoder = false;
         let decoder_start_id = None;
+        let max_position_embeddings = config.max_position_embeddings;
 
         Ok(ReformerGenerator {
             model,
@@ -1101,6 +1103,7 @@ impl ReformerGenerator {
             is_encoder_decoder,
             vocab_size,
             decoder_start_id,
+            max_position_embeddings,
         })
     }
 }
@@ -1138,6 +1141,9 @@ impl PrivateLanguageGenerator<ReformerModelWithLMHead, ReformerVocab, ReformerTo
     fn get_decoder_start_id(&self) -> Option<i64> {
         self.decoder_start_id
     }
+    fn get_max_positions_embeddings(&self) -> i64 {
+        self.max_position_embeddings
+    }
 
     fn prepare_inputs_for_generation<'a>(
         &self,
