@@ -1536,6 +1536,7 @@ pub struct XLNetGenerator {
     is_encoder_decoder: bool,
     vocab_size: i64,
     decoder_start_id: Option<i64>,
+    max_position_embeddings: i64,
 }
 
 impl XLNetGenerator {
@@ -1591,6 +1592,8 @@ impl XLNetGenerator {
         let is_encoder_decoder = false;
         let vocab_size = config.vocab_size;
         let decoder_start_id = None;
+        // XLNet do not have an embedding matrix for position IDs and relies on trigonometric methods instead
+        let max_position_embeddings = i64::MAX;
 
         Ok(XLNetGenerator {
             model,
@@ -1603,6 +1606,7 @@ impl XLNetGenerator {
             is_encoder_decoder,
             vocab_size,
             decoder_start_id,
+            max_position_embeddings,
         })
     }
 }
@@ -1639,6 +1643,10 @@ impl PrivateLanguageGenerator<XLNetLMHeadModel, XLNetVocab, XLNetTokenizer> for
         self.decoder_start_id
     }
 
+    fn get_max_positions_embeddings(&self) -> i64 {
+        self.max_position_embeddings
+    }
+
     fn prepare_inputs_for_generation<'a>(
         &self,
         input_ids: Tensor,
